===================================
Mahotas: Image Processing for numpy
===================================

Contents:

.. toctree::
   :maxdepth: 2

   features
   surf
   thresholding
   distance
   labeled
   polygon
   classification
   faq
   internals
   principles

Indices and tables
==================

* :ref:`genindex`
* :ref:`search`

.. include:: readme.rst

.. automodule:: mahotas
    :members: fullhistogram, otsu, rc, stretch, close_holes, get_structuring_elem, dilate, erode, cwatershed, majority_filter, thin, bwperim, center_of_mass, bbox, croptobbox, sobel, euler, moments, distance, imread, imsave, segmentation, features

